"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const command_1 = require("@oclif/command");
const inquirer = require("inquirer");
const utils_1 = require("../utils");
const targets = ['docker-containers', 'docker-images', 'docker-networks', 'docker-volumes'];
function getCommand(target) {
    switch (target) {
        case 'docker-containers':
            return 'docker rm -f $(docker ps -a -q)';
        case 'docker-images':
            return 'docker rmi $(docker images -q -f dangling=true)';
        case 'docker-networks':
            return 'docker network rm $(docker network ls -q)';
        case 'docker-volumes':
            return 'docker volume rm $(docker volume ls -qf dangling=true)';
        default:
            return '';
    }
}
class Clean extends command_1.Command {
    async run() {
        const { args, flags } = this.parse(Clean);
        const { force } = flags;
        let { target } = args;
        if (!target) {
            let responses = await inquirer.prompt([
                {
                    name: 'target',
                    message: 'What do you want to clean?',
                    type: 'list',
                    choices: targets.map(name => ({ name })),
                },
            ]);
            target = responses.target;
        }
        let confirm = false;
        if (!force) {
            confirm = await inquirer.prompt([
                {
                    name: 'confirm',
                    type: 'confirm',
                    message: `Are you sure you want to clean: ${target}`,
                    default: false,
                },
            ]);
            this.log(`confirm ${confirm}`);
        }
        if (force || confirm) {
            const command = getCommand(target);
            this.log(`🧹 Running command ${command}`);
            try {
                await utils_1.exec(command);
            }
            catch (e) { }
        }
    }
}
Clean.aliases = ['c'];
Clean.description = 'Shortcuts to clean up resources';
Clean.flags = {
    force: command_1.flags.boolean({ char: 'f' }),
};
Clean.args = [
    {
        name: 'target',
        options: targets,
    },
];
exports.default = Clean;
